<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_TW">
<context>
    <name>Application</name>
    <message>
        <location filename="../main.cpp" line="191"/>
        <source>File Manager</source>
        <translation>檔案管理器</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="195"/>
        <source>File Manager is a powerful and easy-to-use file management tool, featured with searching, copying, trash, compression/decompression, file property and other useful functions.</source>
        <translation>檔案管理器是個強大且易用的文件管理工具，有搜尋、複製、垃圾桶功能、壓縮／解壓縮、文件屬性等實用功能。</translation>
    </message>
</context>
</TS>